caellion-python-commons: caellion/pycommons/serializers/datetime_serializer.py File Reference

caellion-python-commons

Classes | Namespaces
datetime_serializer.py File Reference

Go to the source code of this file.

## Classes
class | caellion.pycommons.serializers.datetime_serializer.DateTimeIsoTimeSerializer
| Implementation of DateTime serializer, using IsoTime as a serialized standard. More...
class | caellion.pycommons.serializers.datetime_serializer.DateTimeUnixMillisSerializer
| Implementation of DateTime serializer, using Unix-epoch based timestamp with millisecond precision as serialized format. More...
class | caellion.pycommons.serializers.datetime_serializer.DateTimeUnixMicrosSerializer
| Implementation of DateTime serializer, using Unix-epoch based timestamp with microsecond precision as serialized format. More...
class | caellion.pycommons.serializers.datetime_serializer.DateTimeUnixSerializer
| Implementation of DateTime serializer, using Unix-epoch based timestamp with second precision as serialized format. More...

## Namespaces
| caellion.pycommons.serializers.datetime_serializer
| This module provides various serializers for datetime.datetime object.